@@ -23,13 +23,13 @@
 #include "preferreddevice.h"
 #include "volumemonitor.h"
 
-#include "devicenamesourcemodel.h"
 #include "devicerenamemodel.h"
 #include "devicerenamesaver.h"
 #include "globalconfig.h"
 #include "globalservice.h"
 #include "listitemmenu.h"
 #include "microphoneindicator.h"
+#include "percentvalidator.h"
 #include "speakertest.h"
 #include "volumefeedback.h"
 
@@ -75,7 +75,7 @@ void Plugin::registerTypes(const char *uri)
     qmlRegisterType<GlobalConfig>(uri, 0, 1, "GlobalConfig");
     qmlRegisterType<DeviceRenameModel>(uri, 0, 1, "DeviceRenameModel");
     qmlRegisterType<DeviceRenameSaver>(uri, 0, 1, "DeviceRenameSaver");
-    qmlRegisterType<DeviceNameSourceModel>(uri, 0, 1, "DeviceNameSourceModel");
+    qmlRegisterType<PercentValidator>(uri, 0, 1, "PercentValidator");
     qmlRegisterSingletonType(uri, 0, 1, "PulseAudio", pulseaudio_singleton);
     qmlRegisterSingletonType<MicrophoneIndicator>(uri, 0, 1, "MicrophoneIndicator", [](QQmlEngine *engine, QJSEngine *jsEngine) -> QObject * {
         Q_UNUSED(engine);
